@@ -146,7 +146,7 @@ class SynchronousMultiSpanProcessor(SpanProcessor):
     def add_span_processor(self, span_processor: SpanProcessor) -> None:
         """Adds a SpanProcessor to the list handled by this instance."""
         with self._lock:
-            self._span_processors = self._span_processors + (span_processor,)
+            self._span_processors += (span_processor,)
 
     def on_start(
         self,
@@ -216,7 +216,7 @@ class ConcurrentMultiSpanProcessor(SpanProcessor):
     def add_span_processor(self, span_processor: SpanProcessor) -> None:
         """Adds a SpanProcessor to the list handled by this instance."""
         with self._lock:
-            self._span_processors = self._span_processors + (span_processor,)
+            self._span_processors += (span_processor,)
 
     def _submit_and_await(
         self,
@@ -350,7 +350,7 @@ class ReadableSpan:
         parent: Optional[trace_api.SpanContext] = None,
         resource: Resource = Resource.create({}),
         attributes: types.Attributes = None,
-        events: Sequence[Event] = None,
+        events: Sequence[Event] = (),
         links: Sequence[trace_api.Link] = (),
         kind: trace_api.SpanKind = trace_api.SpanKind.INTERNAL,
         instrumentation_info: InstrumentationInfo = None,
@@ -426,11 +426,11 @@ class ReadableSpan:
 
     @property
     def events(self) -> Sequence[Event]:
-        return MappingProxyType(self._events)
+        return tuple(event for event in self._events)
 
     @property
     def links(self) -> Sequence[trace_api.Link]:
-        return MappingProxyType(self._links)
+        return tuple(link for link in self._links)
 
     @property
     def resource(self) -> Resource:
